@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2013 Martin A. Godisch <martin@godisch.de>
+ * Copyright (c) 2002-2024 Martin A. Godisch <martin@godisch.de>
  */
 
 #include <assert.h>
@@ -13,8 +13,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
-#include <unistd.h>
 #include <time.h>
+#include <unistd.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <X11/xpm.h>
@@ -349,7 +349,7 @@ void do_opts(int argc, char *argv[], int *show_days, char **xdisplay, char **geo
 		case 'v':
 #endif /* SOLARIS */
 			printf("%s %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-			printf("copyright (c) 2002-2013 Martin A. Godisch <martin@godisch.de>\n");
+			printf("copyright (c) 2002-2024 Martin A. Godisch <martin@godisch.de>\n");
 			exit(0);
 #ifdef SOLARIS
 			} else if (!strcmp(argv[i], "--display"))
@@ -515,8 +515,7 @@ int read_log(void)
 	}
 
 	for (line = 1;; line++) {
-		fgets(buffer, sizeof(buffer), F);
-		if (feof(F))
+		if (fgets(buffer, sizeof(buffer), F) == NULL)
 			break;
 
 		if (n == 0) {
@@ -661,7 +660,9 @@ int make_lock(int force)
 				fclose(F);
 				snprintf(proc, sizeof(proc), "/proc/"PID_T"/exe", pid);
 				if (i == 1 && ((i = readlink(proc, buffer, sizeof(buffer)-1)) >= 0 || errno == ENOENT)) {
-					buffer[i] = 0;
+					if (i >= 0) {
+						buffer[i] = 0;
+					}
 					if (i < 0 || ((c = rindex(buffer, '/')) != NULL && strcmp(c+1, "wmwork") != 0)) {
 						fprintf(stderr, "%s: found stale lock file (pid "PID_T")\n", PACKAGE_NAME, pid);
 						return make_lock(1);
